@@ -220,6 +220,7 @@ class LabelBase(Group):
         super().__init__(max_size=1, x=x, y=y, scale=1, **kwargs)
 
         self._font = font
+        self._ascent, self._descent = self._get_ascent_descent()
         self.palette = Palette(2)
         self._color = color
         self._background_color = background_color
@@ -244,7 +245,7 @@ class LabelBase(Group):
         if self.base_alignment:
             self._y_offset = 0
         else:
-            self._y_offset = self._get_ascent() // 2
+            self._y_offset = self._ascent // 2
 
     def _get_ascent_descent(self) -> Tuple[int, int]:
         """ Private function to calculate ascent and descent font values """
@@ -267,9 +268,6 @@ class LabelBase(Group):
                 descender_max = max(descender_max, -this_glyph.dy)
         return ascender_max, descender_max
 
-    def _get_ascent(self) -> int:
-        return self._get_ascent_descent()[0]
-
     @property
     def font(self) -> None:
         """Font to use for text display."""
